@@ -26,13 +26,14 @@
 # Relocated from main file for easier editing
 %BrowsersFamily = (
 	'msie'      => 1,
-	'firefox'   => 2,
-	'netscape'  => 3,
-	'svn'       => 4,
-	'opera'     => 5,
-	'safari'    => 6,
-	'chrome'    => 7,
-	'konqueror' => 8
+	'edge'      => 2,
+	'firefox'   => 3,
+	'netscape'  => 4,
+	'svn'       => 5,
+	'opera'     => 6,
+	'safari'    => 7,
+	'chrome'    => 8,
+	'konqueror' => 9
 );
 
 # BrowsersSearchIDOrder
@@ -121,6 +122,7 @@
 'webfetcher',
 'webexplorer',
 'webmirror',
+'webpositive',          # Must be before safari
 'webvcr',
 'qnx\svoyager',
 # Site grabbers
@@ -270,8 +272,8 @@
 'konqueror','Konqueror',
 'svn', 'Subversion client', 
 'msie','MS Internet Explorer',
+'edge','Edge',
 'netscape','Netscape',
-
 'elinks','ELinks',
 'firebird','Firebird (Old Firefox)',
 'go!zilla','Go!Zilla',
@@ -349,6 +351,7 @@
 'webfetcher','WebFetcher',
 'webexplorer','IBM-WebExplorer',
 'webmirror','WebMirror',
+'webpositive','WebPositive',
 'webvcr','WebVCR',
 'qnx\svoyager','QNX Voyager',
 # Site grabbers
@@ -381,27 +384,27 @@
 'abilon','Abilon (RSS Reader)',
 'aggrevator', 'Aggrevator (RSS Reader)',
 'aiderss', 'AideRSS (RSS Reader)',
-'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank">Akregator (RSS Reader)</a>',  
-'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank">AppleSyndication (RSS Reader)</a>',
+'akregator','<a href="http://akregator.sourceforge.net/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Akregator (RSS Reader)</a>',  
+'applesyndication','<a href="http://www.apple.com/macosx/features/safari/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">AppleSyndication (RSS Reader)</a>',
 'betanews_reader','Betanews Reader (RSS Reader)',
-'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank">BlogBridge (RSS Reader)</a>',
+'blogbridge','<a href="http://www.blogbridge.com/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">BlogBridge (RSS Reader)</a>',
 'cyndicate','Cyndicate (RSS Reader)',
 'feeddemon', 'FeedDemon (RSS Reader)',
 'feedreader', 'FeedReader (RSS Reader)',
-'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank">FeedTools (RSS Reader)</a>',
-'greatnews','<a href="http://www.curiostudio.com/" title="Browser home page [new window]" target="_blank">GreatNews (RSS Reader)</a>',
-'gregarius','<a href="http://devlog.gregarius.net/docs/ua" title="Browser home page [new window]" target="_blank">Gregarius (RSS Reader)</a>',
-'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank">Hatena (RSS Reader)</a>',
+'feedtools','<a href="http://sporkmonger.com/projects/feedtools/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">FeedTools (RSS Reader)</a>',
+'greatnews','<a href="http://www.curiostudio.com/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">GreatNews (RSS Reader)</a>',
+'gregarius','<a href="http://devlog.gregarius.net/docs/ua" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Gregarius (RSS Reader)</a>',
+'hatena_rss','<a href="http://r.hatena.ne.jp/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Hatena (RSS Reader)</a>',
 'jetbrains_omea', 'Omea (RSS Reader)',
-'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank">Liferea (RSS Reader)</a>',
+'liferea','<a href="http://liferea.sourceforge.net/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">Liferea (RSS Reader)</a>',
 'netnewswire', 'NetNewsWire (RSS Reader)',
 'newsfire', 'NewsFire (RSS Reader)',
 'newsgator', 'NewsGator (RSS Reader)',
 'newzcrawler', 'NewzCrawler (RSS Reader)',
 'plagger', 'Plagger (RSS Reader)',
 'pluck', 'Pluck (RSS Reader)',
-'potu','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank">Potu (RSS Reader)</a>',
-'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank">PubSub (RSS Reader)</a>',
+'potu','<a href="http://www.potu.com/" title="Potu Rss-Reader home page [new window]" target="_blank" rel="noopener noreferrer">Potu (RSS Reader)</a>',
+'pubsub\-rss\-reader','<a href="http://www.pubsub.com/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">PubSub (RSS Reader)</a>',
 'pulpfiction', 'PulpFiction (RSS Reader)',
 'rssbandit', 'RSS Bandit (RSS Reader)',
 'rssreader', 'RssReader (RSS Reader)',
@@ -413,7 +416,7 @@
 'shrook', 'Shrook (RSS Reader)',
 'straw', 'Straw (RSS Reader)',
 'syndirella', 'Syndirella (RSS Reader)',
-'vienna', '<a href="http://www.vienna-rss.org/" title="Vienna RSS-Reader [new window]" target="_blank">Vienna (RSS Reader)</a>',
+'vienna', '<a href="http://www.vienna-rss.org/" title="Vienna RSS-Reader [new window]" target="_blank" rel="noopener noreferrer">Vienna (RSS Reader)</a>',
 'wizz\srss\snews\sreader','Wizz RSS News Reader (RSS Reader)',
 # PDA/Phonecell browsers
 'alcatel','Alcatel Browser (PDA/Phone browser)',
@@ -448,9 +451,9 @@
 'webtv','WebTV browser',
 'democracy','Democracy',
 # Anonymous Proxy Browsers (can be used as grabbers as well...)
-'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank">CJB.NET Proxy</a>',
-'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank">OSSProxy</a>',
-'smallproxy','<a href="http://www.smallproxy.ru/" title="SmallProxy home page [new window]" target="_blank">SmallProxy</a>',
+'cjb\.net','<a href="http://proxy.cjb.net/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">CJB.NET Proxy</a>',
+'ossproxy','<a href="http://www.marketscore.com/FAQ.Aspx" title="OSSProxy home page [new window]" target="_blank" rel="noopener noreferrer">OSSProxy</a>',
+'smallproxy','<a href="http://www.smallproxy.ru/" title="SmallProxy home page [new window]" target="_blank" rel="noopener noreferrer">SmallProxy</a>',
 # Other kind of browsers
 'adobeair','AdobeAir',
 'apt','Debian APT',
@@ -460,7 +463,7 @@
 'curl','Curl',
 'csscheck','WDG CSS Validator',
 'httrack','HTTrack',
-'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank">FDM Free Download Manager</a>',
+'fdm','<a href="http://www.freedownloadmanager.org/" title="Browser home page [new window]" target="_blank" rel="noopener noreferrer">FDM Free Download Manager</a>',
 'javaws','Java Web Start',
 'wget','Wget',
 'fget','FGet',
@@ -522,6 +525,7 @@
 'konqueror','konqueror',
 'svn','subversion',
 'msie','msie',
+'edge','edge',
 'netscape','netscape',
 
 'firebird','phoenix',
@@ -575,6 +579,7 @@
 'ncsa_mosaic','ncsa_mosaic',
 'netpositive','netpositive',
 'phoenix','phoenix',
+'webpositive','safari',
 # Site grabbers
 'grabber','grabber',
 'teleport','teleport',
@@ -748,6 +753,9 @@
 
 # Browsers examples by engines
 #
+# -- Edge --
+# Mozilla/5.0 (Windows NT 10.0; <64-bit tags>) AppleWebKit/<WebKit Rev> (KHTML, like Gecko) Chrome/<Chrome Rev> Safari/<WebKit Rev> Edge/<EdgeHTML Rev>.<Windows Build>
+#
 # -- Mosaic --
 # MSIE		4.0  	Mozilla/4.0 (compatible; MSIE 5.0; Windows 98; DigExt; KITV4 Wanadoo; KITV5 Wanadoo)
 #
