@@ -16,11 +16,12 @@
 
 # Relocated from main file for easier editing
 %OSFamily = (
-	'win'   => 'Windows',
-	'mac'   => 'Macintosh',
-	'ios'   => 'iOS',
-	'linux' => 'Linux',
-	'bsd'   => 'BSD'
+  'win'     => 'Windows',
+  'mac'     => 'Macintosh',
+  'ios'     => 'iOS',
+  'android' => 'Android',
+  'linux'   => 'Linux',
+  'bsd'     => 'BSD'
 );
 
 # OSSearchIDOrder
@@ -35,6 +36,7 @@
 'windows[_+ ]?2008', 'windows[_+ ]nt[_+ ]6\.1', # Must be before windows_nt_6
 'windows[_+ ]?2012', 'windows[_+ ]nt[_+ ]6\.2', # Must be before windows_nt_6 = windows 8
 'windows[_+ ]nt[_+ ]6\.3', # Must be before windows_nt_6 = windows 8.1 
+'windows[_+ ]nt[_+ ]11', # Windows 11
 'windows[_+ ]nt[_+ ]10', # Windows 10
 'windows[_+ ]?vista', 'windows[_+ ]nt[_+ ]6',
 'windows[_+ ]?2003','windows[_+ ]nt[_+ ]5\.2',	# Must be before windows_nt_5
@@ -55,6 +57,11 @@
 'ipad',
 'ipod',
 # Macintosh OS family
+'mac[_+ ]os[_+ ]x[_+ ]12',
+'mac[_+ ]os[_+ ]x[_+ ]11',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]15',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]14',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]13',
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]12',
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]11',
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]10',
@@ -68,15 +75,36 @@
 'mac[_+ ]?p',									# This works for macppc and mac_ppc and mac_powerpc
 'mac[_+ ]68',									# This works for mac_6800 and mac_68k
 'macweb',
+'haiku',
 'macintosh',
-# Linux family
+# Android family
+'android[_+ ]13',       # Android 13
+'android[_+ ]12',       # Android 12
+'android[_+ ]11',       # Android 11
+'android[_+ ]10',       # Android 10
+'android[_+ ]9',        # Pie
+'android[_+ ]8',        # Oreo
+'android[_+ ]7',        # Nougat
+'android[_+ ]6',        # Marshmallow
+'android[_+ ]5',        # Lollipop
+'android[_+ ]4[_\.]4',  # KitKat
+'android[_+ ]4[_\.]0',  # Ice Cream Sandwich
+'android[_+ ]4',        # Jelly Bean, Must be after K & I
+'android[_+ ]3',        # Honeycomb
+'android[_+ ]2[_\.]3',  # Gingerbread
+'android[_+ ]2[_\.]2',  # Froyo
+'android[_+ ]2',        # Eclair, Must be after F & G
+'android[_+ ]1[_\.]6',  # Donut
+'android[_+ ]1[_\.]5',  # Cupcake
 'linux(.*)android',
+'android',
+# Linux family
 'linux(.*)asplinux',
 'linux(.*)centos',
 'linux(.*)debian',
 'linux(.*)fedora',
 'linux(.*)gentoo',
-'linux(.*)mandr',
+'linux(.*)mageia',
 'linux(.*)momonga',
 'linux(.*)pclinuxos',
 'linux(.*)red[_+ ]hat',
@@ -86,9 +114,11 @@
 'linux(.*)vine',
 'linux(.*)white\sbox',
 'linux(.*)zenwalk',
-'linux',
-'android',
+'centos',
 'debian',
+'gentoo',
+'ubuntu',
+'linux',
 # Hurd family
 'gnu.hurd',
 # BSDs family
@@ -154,6 +184,7 @@
 'windows[_+ ]?2008','win2008','windows[_+ ]nt[_+ ]6\.1','win7',
 'windows[_+ ]?2012','win2012','windows[_+ ]nt[_+ ]6\.2','win8',
 'windows[_+ ]nt[_+ ]6\.3','win8.1',
+'windows[_+ ]nt[_+ ]11','win11',
 'windows[_+ ]nt[_+ ]10','win10',
 'windows[_+ ]?vista','winvista','windows[_+ ]nt[_+ ]6','winvista',
 'windows[_+ ]?2003','win2003','windows[_+ ]nt[_+ ]5\.2','win2003',
@@ -177,6 +208,11 @@
 'ipad','ios_ipad', #Must be Before Mac OS Family
 'ipod','ios_ipod',  #Must be Before Mac OS Family
 # Macintosh OS family
+'mac[_+ ]os[_+ ]x[_+ ]12','macos12',
+'mac[_+ ]os[_+ ]x[_+ ]11','macos11',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]15','macosx15',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]14','macosx14',
+'mac[_+ ]os[_+ ]x[_+ ]10[_\.]13','macosx13',
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]12','macosx12',
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]11','macosx11',
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]10','macosx10',
@@ -188,14 +224,35 @@
 'mac[_+ ]os[_+ ]x[_+ ]10[_\.]4','macosx4',
 'mac[_+ ]os[_+ ]x','macosx', 'vienna', 'macosx', 'newsfire', 'macosx', 'applesyndication', 'macosx',
 'mac[_+ ]?p','macintosh','mac[_+ ]68','macintosh','macweb','macintosh','macintosh','macintosh',
+'haiku', 'haiku',
+# Android family (androidyyy)
+'android[_+ ]13','android13',              # Android 13
+'android[_+ ]12','android12',              # Android 12
+'android[_+ ]11','android11',              # Android 11
+'android[_+ ]10','android10',              # Android 10
+'android[_+ ]9','androidpie',              # Pie
+'android[_+ ]8','androidoreo',              # Oreo
+'android[_+ ]7','androidnougat',            # Nougat
+'android[_+ ]6','androidmarshmallow',       # Marshmallow
+'android[_+ ]5','androidlollipop',          # Lollipop
+'android[_+ ]4[_\.]4','androidkitkat',      # KitKat
+'android[_+ ]4[_\.]0','androidics',         # Ice Cream Sandwich
+'android[_+ ]4','androidjellybean',         # Jelly Bean, Must be after K & I
+'android[_+ ]3','androidhoneycomb',         # Honeycomb
+'android[_+ ]2[_\.]3','androidgingerbread', # Gingerbread
+'android[_+ ]2[_\.]2','androidfroyo',       # Froyo
+'android[_+ ]2','androideclair',            # Eclair, Must be after F & G
+'android[_+ ]1[_\.]6','androiddonut',       # Donut
+'android[_+ ]1[_\.]5','androidcupcake',     # Cupcake
+'linux(.*)android','android',
+'android','android',
 # Linux family (linuxyyy)
-'linux(.*)android','linuxandroid',
 'linux(.*)asplinux','linuxasplinux',
 'linux(.*)centos','linuxcentos',
 'linux(.*)debian','linuxdebian',
 'linux(.*)fedora','linuxfedora',
 'linux(.*)gentoo','linuxgentoo',
-'linux(.*)mandr','linuxmandr',
+'linux(.*)mageia','linuxmageia',
 'linux(.*)momonga','linuxmomonga',
 'linux(.*)pclinuxos','linuxpclinuxos',
 'linux(.*)red[_+ ]hat','linuxredhat',
@@ -206,8 +263,10 @@
 'linux(.*)white\sbox','linuxwhitebox',
 'linux(.*)zenwalk','linuxzenwalk',
 'linux','linux',
-'android','linuxandroid',
+'centos','linuxcentos',
 'debian','linuxdebian',
+'gentoo','linuxgentoo',
+'ubuntu','linuxubuntu',
 # Hurd family
 'gnu.hurd','gnu',
 # BSDs family (bsdyyy)
@@ -260,51 +319,78 @@
 #-----------------------------------------------------------
 %OSHashLib      = (
 # Windows family OS
+'win11','<a href="http://www.microsoft.com/windows11/" title="Windows 11 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 11</a>',
 'win10','<a href="http://www.microsoft.com/windows10/" title="Windows 10 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 10</a>',
-'win8.1','<a href="http://www.microsoft.com/windows8/" title="Windows 8.1 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 8.1</a>',
-'win8','<a href="http://www.microsoft.com/windows8/" title="Windows 8 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 8</a>',
-'win7','<a href="http://windows.microsoft.com/en-US/windows7/products/home/" title="Windows 7 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 7</a>',
-'winlong','<a href="http://www.microsoft.com/windows/" title="Windows Vista home page [new window]" target="_blank" rel="noopener noreferrer">Windows Vista (LongHorn)</a>',
-'win2008','<a href="http://www.microsoft.com/windowsserver2008/" title="Windows 2008 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 2008</a>',
-'win2012','<a href="http://www.microsoft.com/en-us/server-cloud/windows-server/2012-default.aspx/" title="Windows Server 2012 home page [new window]" target="_blank" rel="noopener noreferrer">Windows Server 2012</a>',
-'winvista','<a href="http://www.microsoft.com/windowsvista/" title="Windows Vista home page [new window]" target="_blank" rel="noopener noreferrer">Windows Vista</a>',
-'win2003','<a href="http://www.microsoft.com/windowsserver2003/" title="Windows 2003 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 2003</a>',
-'winxp','<a href="http://www.microsoft.com/windowsxp/" title="Windows XP home page [new window]" target="_blank" rel="noopener noreferrer">Windows XP</a>',
-'winme','<a href="http://support.microsoft.com/ph/6519/" title="Windows ME support page [new window]" target="_blank" rel="noopener noreferrer">Windows ME</a>',
-'win2000','<a href="http://support.microsoft.com/ph/1131" title="Windows 2000 support page [new window]" target="_blank" rel="noopener noreferrer">Windows 2000</a>',
-'winnt','<a href="http://support.microsoft.com/default.aspx?pr=ntw40" title="Windows NT support page [new window]" target="_blank" rel="noopener noreferrer">Windows NT</a>',
-'win98','<a href="http://support.microsoft.com/w98" title="Windows 98 support page [new window]" target="_blank" rel="noopener noreferrer">Windows 98</a>',
-'win95','<a href="http://support.microsoft.com/ph/7864" title="Windows 95 support page [new window]" target="_blank" rel="noopener noreferrer">Windows 95</a>',
-'win16','<a href="http://www.microsoft.com/windows/WinHistoryDesktop.mspx#E1B" title="Windows 3.xx history page [new window]" target="_blank" rel="noopener noreferrer">Windows 3.xx</a>',
+'win8.1','<a href="https://technet.microsoft.com/en-us/library/hh832030(v=ws.11).aspx" title="Windows 8.1 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 8.1</a>',
+'win8','<a href="https://technet.microsoft.com/en-us/library/hh832030(v=ws.11).aspx" title="Windows 8 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 8</a>',
+'win7','<a href="https://technet.microsoft.com/en-us/library/dd349779.aspx" title="Windows 7 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 7</a>',
+'winlong','<a href="https://technet.microsoft.com/en-us/library/cc707009.aspx" title="Windows Vista home page [new window]" target="_blank" rel="noopener noreferrer">Windows Vista (LongHorn)</a>',
+'win2008','<a href="https://technet.microsoft.com/en-us/library/dd349801(v=ws.10).aspx" title="Windows 2008 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 2008</a>',
+'win2012','<a href="https://technet.microsoft.com/en-us/library/hh801901(v=ws.11).aspx" title="Windows Server 2012 home page [new window]" target="_blank" rel="noopener noreferrer">Windows Server 2012</a>',
+'winvista','<a href="https://technet.microsoft.com/en-us/library/cc707009.aspx" title="Windows Vista home page [new window]" target="_blank" rel="noopener noreferrer">Windows Vista</a>',
+'win2003','<a href="https://www.microsoft.com/en-US/download/details.aspx?id=53314" title="Windows 2003 home page [new window]" target="_blank" rel="noopener noreferrer">Windows 2003</a>',
+'winxp','<a href="https://technet.microsoft.com/en-us/library/bb491054.aspx" title="Windows XP home page [new window]" target="_blank" rel="noopener noreferrer">Windows XP</a>',
+'winme','<a href="https://support.microsoft.com/en-us/help/253695/" title="Windows ME support page [new window]" target="_blank" rel="noopener noreferrer">Windows ME</a>',
+'win2000','<a href="https://technet.microsoft.com/en-us/library/hh534433.aspx" title="Windows 2000 support page [new window]" target="_blank" rel="noopener noreferrer">Windows 2000</a>',
+'winnt','<a href="https://technet.microsoft.com/en-us/library/cc767870.aspx" title="Windows NT support page [new window]" target="_blank" rel="noopener noreferrer">Windows NT</a>',
+'win98','<a href="https://support.microsoft.com/en-us/help/234762/" title="Windows 98 support page [new window]" target="_blank" rel="noopener noreferrer">Windows 98</a>',
+'win95','<a href="https://en.wikipedia.org/wiki/Windows_95" title="Windows 95 Wiki Pedia page [new window]" target="_blank" rel="noopener noreferrer">Windows 95</a>',
+'win16','<a href="https://support.microsoft.com/en-us/help/83245" title="Windows 3.xx history page [new window]" target="_blank" rel="noopener noreferrer">Windows 3.xx</a>',
 'wince','<a href="http://www.microsoft.com/windowsmobile/" title="Windows Mobile home page [new window]" target="_blank" rel="noopener noreferrer">Windows Mobile</a>',
 'winphone','<a href="http://www.microsoft.com/windowsphone/" title="Windows Phone home page [new window]" target="_blank" rel="noopener noreferrer">Windows Phone</a>',
 'winunknown','Windows (unknown version)',
 'winxbox','<a href="http://www.xbox.com/" title="Microsoft XBOX home page [new window]" target="_blank" rel="noopener noreferrer">Microsoft XBOX</a>',
 # Macintosh OS
-'macosx12','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.12 Sierra</a>',
-'macosx11','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.11 El Capitan</a>',
-'macosx10','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.10 Yosemite</a>',
-'macosx9','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.9 Mavericks</a>',
-'macosx8','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.8 Mountain Lion</a>',
-'macosx7','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.7 Lion</a>',
-'macosx6','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.6 Snow Leopard</a>',
-'macosx5','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.5 Leopard</a>',
-'macosx4','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.4 Tiger</a>',
-'macosx','<a href="http://www.apple.com/macosx/" title="Mac OS X home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X others</a>',
-'macintosh','<a href="http://www.apple.com/" title="Mac OS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS</a>',
+'macos12','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">macOS 12 Monterey</a>',
+'macos11','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">macOS 11 Big Sur</a>',
+'macosx15','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">macOS 10.15 Catalina</a>',
+'macosx14','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">macOS 10.14 Mojave</a>',
+'macosx13','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">macOS 10.13 High Sierra</a>',
+'macosx12','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">macOS 10.12 Sierra</a>',
+'macosx11','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">OS X 10.11 El Capitan</a>',
+'macosx10','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">OS X 10.10 Yosemite</a>',
+'macosx9','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">OS X 10.9 Mavericks</a>',
+'macosx8','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">OS X 10.8 Mountain Lion</a>',
+'macosx7','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.7 Lion</a>',
+'macosx6','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.6 Snow Leopard</a>',
+'macosx5','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.5 Leopard</a>',
+'macosx4','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X 10.4 Tiger</a>',
+'macosx','<a href="https://www.apple.com/macos/" title="macOS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS X others</a>',
+'macintosh','<a href="https://www.apple.com/" title="Mac OS home page [new window]" target="_blank" rel="noopener noreferrer">Mac OS</a>',
+'Haiku', '<a href="http://www.haiku-os.org" title="Haiku home page [new window]" target="_blank" rel="noopener noreferrer">Haiku</a>',
+# Android
+'android13','<a href="https://developer.android.com/about/versions/13" title="Google Android 13.x home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 13.x</a>',
+'android12','<a href="https://developer.android.com/about/versions/12" title="Google Android 12.x home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 12.x</a>',
+'android11','<a href="https://developer.android.com/about/versions/11" title="Google Android 11.x home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 11.x</a>',
+'android10','<a href="https://developer.android.com/about/versions/10" title="Google Android 10.x home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 10.x</a>',
+'androidpie','<a href="https://developer.android.com/about/versions/pie/" title="Google Android 9.x Pie home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 9.x Pie</a>',
+'androidoreo','<a href="https://developer.android.com/about/versions/oreo/" title="Google Android 8.x Oreo home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 8.x Oreo</a>',
+'androidnougat','<a href="https://developer.android.com/about/versions/nougat/" title="Google Android 7.x Nougat home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 7.x Nougat</a>',
+'androidmarshmallow','<a href="https://developer.android.com/about/versions/marshmallow/" title="Google Android 6.x Marshmallow home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 6.x Marshmallow</a>',
+'androidlollipop','<a href="https://developer.android.com/about/versions/lollipop.html" title="Google Android 5.x Lollipop home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 5.x Lollipop</a>',
+'androidkitkat','<a href="https://developer.android.com/about/versions/kitkat.html" title="Google Android 4.4 KitKat home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 4.4 KitKat</a>',
+'androidjellybean','<a href="https://developer.android.com/about/versions/jelly-bean.html" title="Google Android 4.1-4.3 Jelly Bean home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 4.1-4.3 Jelly Bean</a>',
+'androidics','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 4.0 Ice Cream Sandwich</a>',
+'androidhoneycomb','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 3.x Honeycomb</a>',
+'androidgingerbread','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 2.3 Gingerbread</a>',
+'androidfroyo','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 2.2 Froyo</a>',
+'androideclair','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 2.0-2.1 Eclair</a>',
+'androiddonut','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 1.6 Donut</a>',
+'androidcupcake','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android 1.5 Cupcake</a>',
+'android','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android Unknown</a>',
+'linuxandroid','<a href="https://developer.android.com/index.html" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android Unknown</a>',
 # Linux
-'linuxandroid','<a href="http://code.google.com/android/" title="Google Android home page [new window]" target="_blank" rel="noopener noreferrer">Google Android</a>',
 'linuxasplinux','<a href="http://www.asplinux.ru/" title="ASPLinux home page [new window]" target="_blank" rel="noopener noreferrer">ASPLinux</a>',
-'linuxcentos','<a href="http://www.centos.org/" title="Centos home page [new window]" target="_blank" rel="noopener noreferrer">Centos</a>',
-'linuxdebian','<a href="http://www.debian.org/" title="Debian home page [new window]" target="_blank" rel="noopener noreferrer">Debian</a>',
-'linuxfedora','<a href="http://fedora.redhat.com/" title="Fedora home page [new window]" target="_blank" rel="noopener noreferrer">Fedora</a>',
-'linuxgentoo','<a href="http://www.gentoo.org/" title="Gentoo home page [new window]" target="_blank" rel="noopener noreferrer">Gentoo</a>',
-'linuxmandr','<a href="http://www.mandriva.com/" title="Mandriva (former Mandrake) home page [new window]" target="_blank" rel="noopener noreferrer">Mandriva (or Mandrake)</a>',
+'linuxcentos','<a href="https://www.centos.org/" title="Centos home page [new window]" target="_blank" rel="noopener noreferrer">Centos</a>',
+'linuxdebian','<a href="https://www.debian.org/" title="Debian home page [new window]" target="_blank" rel="noopener noreferrer">Debian</a>',
+'linuxfedora','<a href="https://getfedora.org/" title="Fedora home page [new window]" target="_blank" rel="noopener noreferrer">Fedora</a>',
+'linuxgentoo','<a href="https://www.gentoo.org/" title="Gentoo home page [new window]" target="_blank" rel="noopener noreferrer">Gentoo</a>',
+'linuxmageia','<a href="https://www.mageia.org/" title="Mageia home page [new window]" target="_blank" rel="noopener noreferrer">Mageia</a>',
 'linuxmomonga','<a href="http://www.momonga-linux.org/" title="Momonga Linux home page [new window]" target="_blank" rel="noopener noreferrer">Momonga Linux</a>',
 'linuxpclinuxos','<a href="http://www.pclinuxos.com/" title="PCLinuxOS home page [new window]" target="_blank" rel="noopener noreferrer">PCLinuxOS</a>',
 'linuxredhat','<a href="http://www.redhat.com/" title="Red Hat home page [new window]" target="_blank" rel="noopener noreferrer">Red Hat</a>',
-'linuxsuse','<a href="http://www.novell.com/linux/suse/" title="Suse home page [new window]" target="_blank" rel="noopener noreferrer">Suse</a>',
-'linuxubuntu','<a href="http://www.ubuntulinux.org/" title="Ubuntu home page [new window]" target="_blank" rel="noopener noreferrer">Ubuntu</a>',
+'linuxsuse','<a href="https://www.suse.com/" title="Suse home page [new window]" target="_blank" rel="noopener noreferrer">Suse</a>',
+'linuxubuntu','<a href="https://www.ubuntu.com/" title="Ubuntu home page [new window]" target="_blank" rel="noopener noreferrer">Ubuntu</a>',
 'linuxvector','<a href="http://vectorlinux.com/" title="VectorLinux home page [new window]" target="_blank" rel="noopener noreferrer">VectorLinux</a>',
 'linuxvine','<a href="http://www.vinelinux.org/index-en.html" title="Vine Linux home page [new window]" target="_blank" rel="noopener noreferrer">Vine Linux</a>',
 'linuxwhitebox','<a href="http://whiteboxlinux.org/" title="White Box Linux home page [new window]" target="_blank" rel="noopener noreferrer">White Box Linux</a>',
@@ -372,3 +458,4 @@
 #  Windows 98 retail, OEM     4.10.1998                    5/11/98
 #  Windows 98 Second Edition  4.10.2222A                   4/23/99
 #  Windows Me                 4.90.3000
+
