@@ -43,6 +43,39 @@
 #
 #-------------------------------------------------------
 
+# 2024-07-17 Dinko Sotirov
+#              Added Amazonbot (https://developer.amazon.com/support/amazonbot)
+#              Added GPTBot (https://openai.com/gptbot)
+#              Added GeedoProductSearch (http://www.geedo.com/product-search.html)
+
+# 2023-07-04 RobC 
+#              Removed Dalvik as native Android UI Browser User Agent
+#              Removed CFNetwork as native iOS and OSX Browser User Agent
+
+# 2021-05--05 RobC
+
+# Removed Baidu catchall because its picking up baidu.sogo.uc.UCBrowser which is a phone browser
+# Added baiduspider- catchall instead
+
+# Newly added from 2021-05-05
+# Adsbot
+# BW/
+# Bytespider
+# CheckMarkNetwork/
+# DuckDuckBot
+# # Foregenix Web Scan
+# IonCrawl
+# Linguee Bot
+# Neevabot
+# PetalBot
+# TkBot
+# vuhuvBot
+
+
+# 2018-03-13 RobC 
+#              Added 36 robots and one generic ( survey ) using v 7.7 robots file as base. 
+#              Also moved robot "Obot" into generics so that it is singled out as an individual Robot.         
+#
 # 2016-09-02 RobC 
 #              Fixed a few errors and added a few missing bots from awstats 7.5 release.
 #
@@ -117,7 +150,7 @@
 # 2005-12-15
 #		added FAST Enteprise Crawler/6 (www dot fastsearch dot com). Note spelling Enteprise not Enterprise.
 #		added findlinks http://wortschatz.uni-leipzig.de/findlinks/
-#		added IBM Almaden Research Center WebFountain http://www.almaden.ibm.com/cs/crawler [hc3]
+#		added IBM Almaden Research Center WebFountain™ http://www.almaden.ibm.com/cs/crawler [hc3]
 #		added INFOMINE/8.0 VLCrawler (http://infomine.ucr.edu/useragents)
 #		added lmspider (lmspider@scansoft.com) http://www.nuance.com/
 #		added noxtrumbot http://www.noxtrum.com/
@@ -394,6 +427,7 @@
 # Note: Robots IDs are in lower case, '_', ' ' and '+' are changed into '[_+\s]' and are quoted.
 #-------------------------------------------------------
 
+
 @RobotsSearchIDOrder_list1 = (
 # Common robots (In robot file)
 'bingbot/',
@@ -407,11 +441,13 @@
 'Google[\x20]Web[\x20]Preview',
 'Googlebot\-Image/',
 'Googlebot\-Mobile/',
+'Google[\x20]Page[\x20]Speed',
 'google\-sitemaps',
 'Googlebot\-News',
 'Googlebot\-Video/',
 'AdsBot\-Google[\x20]\(',
 'AdsBot\-Google\-Mobile\-Apps',
+'Adsbot',
 'Mediapartners-Google',
 'Feedfetcher\-Google',
 'Google\-Adwords\-Instant',
@@ -420,12 +456,16 @@
 'Yahoo![\x20]Slurp',
 'Baiduspider/',
 'Baiduspider\-image',
-'baidu',
+'Baiduspider-',
 'YandexBot/',
 'YandexImages/',
+'YandexImageResizer',
 'YandexMetrika/',
 'YandexMobileBot/',
 'yandex',
+'Amazonbot/',
+'GPTBot/',
+'GeedoProductSearch/',
 'electricmonk/',
 'spbot/',
 'SeznamBot/',
@@ -438,39 +478,63 @@
 'Abrave',
 'acapbot/',
 'Accoona\-AI\-Agent/',
+'arcemedia',
 'AdnormCrawlerCatchBot/',
+'adscanner',
 'aiHitBot/',
 'aipbot/',
+'AlphaBot',
 'Apache\-HttpClient/',
 'Apexoo[\x20]Spider',
 'Applebot/',
 'archive\.org_bot',
 'Babya[\x20]Discoverer',
+'Barkrowler',
 'BDCbot/',
+'BellPagesCA/',
+'BeNosey[\x20]Mohawk[\x20]Search',
+'bhcBot',
+'bidswitchbot',
+'BigBozz/',
 'BinGet/',
+'bitlybot',
 'bl\.uk_lddc_bot/',
 'BLEXBot/',
+'bnf.fr_bot',
 'boitho\.com\-dc/',
+'BoogleBot',
 'BusinessBot:',
+'BW/',
+'Bytespider',
 'CatchBot/',
 'CB/Nutch',
 'CCBot/',
+'CheckMarkNetwork/',
 'Cliqzbot/',
 'CMS[\x20]Crawler',
+'Companybook\-Crawler',
 'ConveraCrawler/',
+'Contacts-Crawler',
+'contxbot',
 'cosmos/',
 'crawl/Nutch',
 'crawler4j',
 'CRAZYWEBCRAWLER',
+'CRMNLCrawlAgent',
 'CSE[\x20]HTML[\x20]Validator',
 'C\-T[\x20]bot',
+'CUBOT',
 'Curl/PHP',
-'Dalvik/',
+'cyencebot',
 'DataCrawler/',
+'daumoa',
+'daum',
 'Deepnet[\x20]Explorer',
 'DeuSu/',
 'Digincore',
 'Discordbot/',
+'Dispatch/',
+'DnyzBot',
 'DoCoMo/',
 'Domain[\x20]Re\-Animator[\x20]Bot',
 'DomainCrawler/',
@@ -478,14 +542,19 @@
 'DomainSONOCrawler/',
 'DomainStatsBot/',
 'DotBot/',
+'DuckDuckBot-Https',
+'DuckDuckBot',
 'DuckDuckGo\-Favicons\-Bot/',
 'ELinks/',
 'ELinks[\x20]\(',
 'EmailMarketingRobot/',
 'EmeraldShield\.com[\x20]WebBot',
 'envolk\[ITS\]spider/',
+'eright',
 'EsperanzaBot',
 'Exabot/',
+'ExtLinksBot',
+'ExperianCrawlUK',
 'facebookexternalhit/',
 'fast_enterprise_crawler.*scrawleradmin\.t\-info@telekom\.de',
 'fast_enterprise_crawler.*t\-info_bi_cluster_crawleradmin\.t\-info@telekom\.de',
@@ -494,43 +563,61 @@
 'findlinks/',
 'Findxbot/',
 'FirePHP/',
+'firstdirectory\-bot',
+'flamingo',
 'FlippyBearBot/',
+'^foo$',
+'Foregenix[\x20]Web[\x20]Scan',
 'FreeWebMonitoring[\x20]SiteChecker/',
 'fujilabol',
 'FurlBot/',
 'Gaisbot/',
 'Gallent[\x20]Spider',
 'GarlikCrawler/',
+'Getintent[\x20]Crawler',
 'GetintentCrawler[\x20]getintent\.com',
 'Gigabot/',
 'gipo\-crawler/Nutch',
 'Girafabot',
 'Gluten[\x20]Free[\x20]Crawler/',
 'gocrawl',
+'Gowikibot',
+'Go\-http\-client/',
 'GrapeshotCrawler/',
 'GSiteCrawler/',
 'GurujiBot/',
+'hadiBot',
 'HaosouSpider',
+'HELLO[\x20]Crawler',
 'holmes/',
+'houzzbot',
 'HTTP_Request2/',
 'HubSpot[\x20]Webcrawler',
 'HyperCrawl/',
 'ICC\-Crawler/',
 'iconoclast',
 'IDGCrawler/Nutch',
+'IDG/UK',
 'idmarch[\x20]Automatic\.beta/',
+'InbyBot',
 'Incutio[\x20]XML',
+'IndeedBot',
 'InfluenceBot',
+'IonCrawl',
 'IRLbot/',
 'IssueCrawler',
 'istellabot/',
 'James[\x20]BOT',
 'Jigsaw/',
 'JobFeed',
+'Jooblebot',
 'KomodiaBot/',
 'Konqueror/',
+'laserlikebot',
+'Lightspeed',
 'linkapediabot',
 'metager\-linkchecker',
+'Linguee[\x20]Bot',
 'linkchecker',
 'LinkCheck',
 'linkdexbot/',
@@ -540,48 +627,65 @@
 'LinksManager\.com_bot',
 'LWP::Simple/',
 'Mail\.RU_Bot/',
+'makecontact',
+'mappy',
+'MauiBot',
 'meanpathbot/',
+'Mechanize',
 'Mediatoolkitbot',
 'MegaIndex\.ru/',
 'merzscope',
+'Meta_Bot',
 'mfibot/',
 'microsoft.*discovery',
 'missigua_locator',
 'MixrankBot',
 'MJ12bot/',
-'MojeekBot/',
+'MojeekBot',
 'Mojolicious',
 'MXT/Nutch',
 'My[\x20]Nutch[\x20]Spider/',
 'myse/Nutch',
+'Naaraa',
+'Neevabot',
 'NerdyBot',
 'netEstate[\x20]NE[\x20]Crawler',
 'NetResearchServer/',
+'Nimbostratus-Bot',
+'nominet',
 'NRLCorpusBuilder/Nutch',
 'nutch\-1\.4/',
 'nutch\-1\.8/',
 'NutchCVS/',
 'o\.uk[\x20]robot',
-'oBot/',
 'ocrawler;',
 'ODP[\x20]link[\x20]checker',
 'Offline[\x20]Explorer/',
 'OmniExplorer_Bot/',
 'OrangeBot/',
+'Orliac',
+'OutclicksBot',
 'PageBitesHyperBot/',
+'Pcore',
 'pdffillerbot/',
+'peopleman',
+'PetalBot',
 'PhantomJS',
 'PHP/5\.2\.8',
+'Pinterestbot',
+'PiplBot',
 'Ploetz[\x20]\+[\x20]Zeller',
 'Plukkie/',
 'Princetonbot/',
 'PrivacyAwareBot/',
+'Prlog/',
 'proximic',
 'psbot/',
 'psbot\-image',
 'python_wk_crawler',
 'Python\-urllib/',
 'QCrawl',
+'Quick-Crawler',
 'ResearchBot',
 'roboto',
 'rogerbot/',
@@ -592,12 +696,16 @@
 'SafeSearch[\x20]microdata[\x20]crawler',
 'safesearch',
 'SBL\-BOT',
+'scrapy',
 'Screaming[\x20]Frog[\x20]SEO[\x20]Spider/',
 'ScreenerBot[\x20]Crawler[\x20]Beta',
+'Scrubby',
 'Searchie/',
+'SecurityResearch\.bot',
 'Seekmo',
 'semanticbot',
 'SemrushBot/',
+'SemrushBot-SI',
 'seo\-audit\-check\-bot/',
 'Seobility',
 'SEOkicks\-Robot',
@@ -605,15 +713,20 @@
 'SEOstats',
 'Seosys/Nutch',
 'Seoterritory\.com[\x20]bot',
+'serendeputy',
 'Shim\-Crawler',
 'SiteExplorer/',
 'siteexplorer\.info',
+'siteimprove',
 'Slackbot\-LinkExpanding',
 'SmabblerBot/',
 'Sogou[\x20]web[\x20]spider/',
 'special_archiver/',
 'Spiderbot/',
+'SpuhexBot',
+'spyonweb',
 'ssearch_bot',
+'Streamline3Bot',
 'SurdotlyBot/',
 'SurveyBot/',
 'taiil/Nutch',
@@ -623,24 +736,34 @@
 'Test/Nutch',
 'Test[\x20]Spider',
 'TestCrawler',
+'The[\x20]Knowledge[\x20]AI',
+'TkBot',
+'tracemyfile',
+'trendiction',
 'TurnitinBot/',
 'TurnitinBot',
 'TweetmemeBot/',
 'UCY/Nutch',
+'uni-leipzig\.de',
 'Uptimebot/',
+'UptimeRobot/',
 'URL[\x20]Checker',
 'UXCrawlerBot',
 'Validator\.nu/',
 'vBSEO',
 'vBulletin[\x20]via[\x20]PHP',
 'vebidoobot',
+'vegi[\x20]bot',
+'Velen',
 'viz/Nutch',
 'VoilaBot',
 'VORTEX/',
 'voyager/',
+'vuhuvBot',
 'W3C_Validator/',
 'W3C\-checklink/',
 'WBSearchBot/',
+'WbSrch/',
 'WeSEE:Ads/PageBot',
 'WeSEE:Ads/PictureBot',
 'WeSEE_Bot',
@@ -656,8 +779,11 @@
 'XoviBot/',
 'yacybot',
 'Yahoo[\x20]Link[\x20]Preview',
+'yak',
 'YisouSpider',
 'yoozBot',
+'Your\-Website\-Sucks',
+'zoominfobot',
 'zspider/',
 'ZumBot/',
 # below placed at end to catch some generics
@@ -665,7 +791,6 @@
 'ng/1\.',
 'ng/2\.',
 'libwww\-perl',
-'CFNetwork',
 'urllib',
 'javabee',
 'projectwf\-java\-test\-crawler',
@@ -696,6 +821,7 @@
 'MSIE[\x20]4',
 'MSIE[\x20]5',
 'MSIE[\x20]6',
+'MSIE\+6\.0\;',
 'Windows[\x20]95',
 'Windows[\x20]98',
 
@@ -816,7 +942,6 @@
 'cyberspyder',
 'datafountains/dmoz_downloader',
 'dataprovider\.com',
-'daumoa',
 'daviesbot',
 'daylifefeedfetcher',
 'daypopbot',
@@ -1322,6 +1447,8 @@
 'ucsd',
 'udmsearch',
 'ultraseek',
+'um\-IC',
+'um\-LN',
 'unchaos_bot_hybrid_web_search_engine',
 'unido\-bot',
 'unisterbot',
@@ -1468,12 +1595,15 @@
 'sitemap',
 'spider',
 'sucker',
+'survey',
 'validator',
 'bot[\s_+:,\.\;\/\\\-]',
 '[\s_+:,\.\;\/\\\-]bot',
 'curl',
 'php',
 'ruby/',
+# Moving oBot here so it doesn't get assigned for other *obot robots
+'oBot/',
 'no_user_agent'
 );
 
@@ -1494,11 +1624,13 @@
 'Google[\x20]Web[\x20]Preview','Google Web Preview',
 'Googlebot\-Image/','Googlebot-Image',
 'Googlebot\-Mobile/','Googlebot-Mobile',
+'Google[\x20]Page[\x20]Speed','Google Page Speed',
 'google\-sitemaps','google-sitemaps',
 'Googlebot\-News','Googlebot-News',
 'Googlebot\-Video/','Googlebot-Video',
 'AdsBot\-Google[\x20]\(','AdsBot-Google',
 'AdsBot\-Google\-Mobile\-Apps','AdsBot-Google-Mobile-Apps',
+'Adsbot','Adsbot',
 'Mediapartners\-Google','Mediapartners-Google',
 'Feedfetcher\-Google','Feedfetcher-Google',
 'Google\-Adwords\-Instant','Google-Adwords-Instant',
@@ -1507,12 +1639,16 @@
 'Yahoo![\x20]Slurp','Yahoo! Slurp',
 'Baiduspider/','Baiduspider',
 'Baiduspider\-image','Baiduspider-image',
-'baidu','Baidu ( catchall )',
+'Baiduspider-','Baiduspider ( catchall )',
 'YandexBot/','YandexBot',
 'YandexImages/','YandexImages',
+'YandexImageResizer','YandexImageResizer',
 'YandexMetrika/','YandexMetrika',
 'YandexMobileBot/','YandexMobileBot',
 'yandex','Yandex ( catchall )',
+'Amazonbot/','Amazonbot',
+'GPTBot/','GPTBot',
+'GeedoProductSearch/','GeedoProductSearch',
 'electricmonk/','electricmonk',
 'spbot/','spbot',
 'SeznamBot/','SeznamBot',
@@ -1526,38 +1662,62 @@
 'acapbot/','acapbot',
 'Accoona\-AI\-Agent/','Accoona-AI-Agent',
 'AdnormCrawlerCatchBot/','AdnormCrawlerCatchBot',
+'adscanner','adscanner',
 'aiHitBot/','aiHitBot',
 'aipbot/','aipbot',
+'AlphaBot','AlphaBot',
 'Apache\-HttpClient/','Apache-HttpClient',
 'Apexoo[\x20]Spider','Apexoo Spider',
 'Applebot/','Applebot',
+'arcemedia','AdsBot-ArceMedia',
 'archive\.org_bot','archive.org_bot',
 'Babya[\x20]Discoverer','Babya Discoverer',
+'Barkrowler','Barkrowler',
 'BDCbot/','BDCbot',
+'BellPagesCA/','BellPagesCA',
+'BeNosey[\x20]Mohawk[\x20]Search','BeNosey Mohawk Search',
+'bhcBot','bhcBot',
+'bidswitchbot','bidswitchbot',
+'BigBozz/','BigBozz',
 'BinGet/','BinGet',
+'bitlybot','bit.ly',
 'bl\.uk_lddc_bot/','bl.uk_lddc_bot',
 'BLEXBot/','BLEXBot',
+'bnf.fr_bot','bnf.fr_bot',
 'boitho\.com\-dc/','boitho.com-dc',
+'BoogleBot','BoogleBot',
 'BusinessBot:','BusinessBot:',
+'BW/','BW',
+'Bytespider','Bytespider',
 'CatchBot/','CatchBot',
 'CB/Nutch','CB/Nutch',
 'CCBot/','CCBot',
+'CheckMarkNetwork/','CheckMarkNetwork',
 'Cliqzbot/','Cliqzbot',
 'CMS[\x20]Crawler','CMS Crawler',
+'Companybook\-Crawler','Companybook-Crawler',
 'ConveraCrawler/','ConveraCrawler',
+'Contacts-Crawler','Contacts-Crawler',
+'contxbot','contxbot',
 'cosmos/','cosmos',
+'CRMNLCrawlAgent','CRMNLCrawlAgent',
 'crawl/Nutch','crawl/Nutch',
 'crawler4j','crawler4j',
 'CRAZYWEBCRAWLER','CRAZYWEBCRAWLER',
 'CSE[\x20]HTML[\x20]Validator','CSE HTML Validator',
 'C\-T[\x20]bot','C-T bot',
+'CUBOT','CUBOT',
 'Curl/PHP','Curl/PHP',
-'Dalvik/','Dalvik',
+'cyencebot','cyencebot',
 'DataCrawler/','DataCrawler',
+'daumoa','daumoa',
+'daum','daum',
 'Deepnet[\x20]Explorer','Deepnet Explorer',
 'DeuSu/','DeuSu',
 'Digincore','Digincore',
 'Discordbot/','Discordbot',
+'Dispatch/','Dispatch',
+'DnyzBot','DnyzBot',
 'DoCoMo/','DoCoMo',
 'Domain[\x20]Re\-Animator[\x20]Bot','Domain Re-Animator Bot',
 'DomainCrawler/','DomainCrawler',
@@ -1565,14 +1725,19 @@
 'DomainSONOCrawler/','DomainSONOCrawler',
 'DomainStatsBot/','DomainStatsBot',
 'DotBot/','DotBot',
+'DuckDuckBot-Https','DuckDuckBot-Https',
+'DuckDuckBot','DuckDuckBot',
 'DuckDuckGo\-Favicons\-Bot/','DuckDuckGo-Favicons-Bot',
 'ELinks/','ELinks',
 'ELinks[\x20]\(','ELinks (',
 'EmailMarketingRobot/','EmailMarketingRobot',
 'EmeraldShield\.com[\x20]WebBot','EmeraldShield.com WebBot',
 'envolk\[ITS\]spider/','envolk ITS spider',
+'eright','eright',
 'EsperanzaBot','EsperanzaBot',
 'Exabot/','Exabot',
+'ExtLinksBot','ExtLinksBot',
+'ExperianCrawlUK','ExperianCrawlUK',
 'facebookexternalhit/','facebookexternalhit',
 'fast_enterprise_crawler.*scrawleradmin\.t\-info@telekom\.de','FAST Enterprise crawleradmin.t-info@telekom.de',
 'fast_enterprise_crawler.*t\-info_bi_cluster_crawleradmin\.t\-info@telekom\.de','FAST Enterprise T-Info_BI_cluster crawleradmin.t-info@telekom.de',
@@ -1581,43 +1746,60 @@
 'findlinks/','findlinks',
 'Findxbot/','Findxbot',
 'FirePHP/','FirePHP',
+'firstdirectory\-bot','firstdirectory-bot',
+'flamingo','Flamingo_SearchEngine',
 'FlippyBearBot/','FlippyBearBot',
+'^foo$','foo',
+'Foregenix[\x20]Web[\x20]Scan','Foregenix Web Scan',
 'FreeWebMonitoring[\x20]SiteChecker/','FreeWebMonitoring SiteChecker',
 'fujilabol','fujilabol',
 'FurlBot/','FurlBot',
 'Gaisbot/','Gaisbot',
 'Gallent[\x20]Spider','Gallent Spider',
 'GarlikCrawler/','GarlikCrawler',
+'Getintent[\x20]Crawler','GetIntent Crawler',
 'GetintentCrawler[\x20]getintent\.com','GetintentCrawler getintent.com',
 'Gigabot/','Gigabot',
 'gipo\-crawler/Nutch','gipo-crawler/Nutch',
 'Girafabot','Girafabot',
 'Gluten[\x20]Free[\x20]Crawler/','Gluten Free Crawler',
 'gocrawl','gocrawl',
+'Gowikibot','Gowikibot',
+'Go\-http\-client/','Go-http-client',
 'GrapeshotCrawler/','GrapeshotCrawler',
 'GSiteCrawler/','GSiteCrawler',
 'GurujiBot/','GurujiBot',
+'hadiBot','hadiBot',
 'HaosouSpider','HaosouSpider',
+'HELLO[\x20]Crawler','HELLO Crawler',
 'holmes/','holmes',
+'houzzbot','houzzbot',
 'HTTP_Request2/','HTTP_Request2',
 'HubSpot[\x20]Webcrawler','HubSpot Webcrawler',
 'HyperCrawl/','HyperCrawl',
 'ICC\-Crawler/','ICC-Crawler',
 'iconoclast','iconoclast',
 'IDGCrawler/Nutch','IDGCrawler/Nutch',
+'IDG/UK','IDG/UK',
 'idmarch[\x20]Automatic\.beta/','idmarch Automatic.beta',
+'InbyBot','InbyBot',
 'Incutio[\x20]XML','Incutio XML',
+'IndeedBot','IndeedBot',
 'InfluenceBot','InfluenceBot',
+'IonCrawl','IonCrawl',
 'IRLbot/','IRLbot',
 'IssueCrawler','IssueCrawler',
 'istellabot/','istellabot',
 'James[\x20]BOT','James BOT',
 'Jigsaw/','Jigsaw',
 'JobFeed','JobFeed',
+'Jooblebot','Jooblebot',
 'KomodiaBot/','KomodiaBot',
 'Konqueror/','Konqueror',
+'Lightspeed','Lightspeed',
 'linkapediabot','linkapediabot',
 'metager\-linkchecker','metager-linkchecker',
+'Linguee[\x20]Bot','Linguee Bot',
 'linkchecker','linkchecker',
 'LinkCheck','LinkCheck',
 'linkdexbot/','linkdexbot',
@@ -1627,48 +1809,66 @@
 'LinksManager\.com_bot','LinksManager.com_bot',
 'LWP::Simple/','LWP::Simple',
 'Mail\.RU_Bot/','Mail.RU Bot',
+'makecontact','makecontact',
+'mappy','Mappy Crawler',
+'MauiBot','MauiBot',
 'meanpathbot/','meanpathbot',
+'Mechanize','Mechanize',
 'Mediatoolkitbot','Mediatoolkitbot',
 'MegaIndex\.ru/','MegaIndex.ru',
 'merzscope','merzscope',
+'Meta_Bot','Meta_Bot',
 'mfibot/','mfibot',
 'microsoft.*discovery','Microsoft Office Protocol Discovery',
 'missigua_locator','missigua_locator',
 'MixrankBot','MixrankBot',
 'MJ12bot/','MJ12bot',
+'mojeek','mojeek',
 'MojeekBot/','MojeekBot',
 'Mojolicious','Mojolicious',
 'MXT/Nutch','MXT/Nutch',
 'My[\x20]Nutch[\x20]Spider/','My Nutch Spider',
 'myse/Nutch','myse/Nutch',
+'Naaraa','Naaraa',
+'Neevabot','Neevabot',
 'NerdyBot','NerdyBot',
 'netEstate[\x20]NE[\x20]Crawler','netEstate NE Crawler',
 'NetResearchServer/','NetResearchServer',
+'Nimbostratus-Bot','Nimbostratus-Bot',
+'nominet','nominet',
 'NRLCorpusBuilder/Nutch','NRLCorpusBuilder/Nutch',
 'nutch\-1\.4/','nutch-1.4',
 'nutch\-1\.8/','nutch-1.8',
 'NutchCVS/','NutchCVS',
 'o\.uk[\x20]robot','o uk.robot',
-'oBot/','oBot',
 'ocrawler;','ocrawler;',
 'ODP[\x20]link[\x20]checker','ODP link checker',
 'Offline[\x20]Explorer/','Offline Explorer',
 'OmniExplorer_Bot/','OmniExplorer_Bot',
 'OrangeBot/','OrangeBot',
+'Orliac','Orliac',
+'OutclicksBot','OutclicksBot',
 'PageBitesHyperBot/','PageBitesHyperBot',
+'Pcore','Pcore',
 'pdffillerbot/','pdffillerbot',
+'peopleman','peopleman',
+'PetalBot','PetalBot',
 'PhantomJS','PhantomJS',
 'PHP/5\.2\.8','PHP/5.2.8',
+'Pinterestbot','Pinterestbot',
+'PiplBot','PiplBot',
 'Ploetz[\x20]\+[\x20]Zeller','Ploetz + Zeller',
 'Plukkie/','Plukkie',
 'Princetonbot/','Princetonbot',
 'PrivacyAwareBot/','PrivacyAwareBot',
+'Prlog/','Prlog',
 'proximic','proximic',
 'psbot/','psbot',
 'psbot\-image','psbot-image',
 'python_wk_crawler','python_wk_crawler',
 'Python\-urllib/','Python-urllib',
 'QCrawl','QCrawl',
+'Quick-Crawler','Quick-Crawler',
 'ResearchBot','ResearchBot',
 'roboto','roboto',
 'rogerbot/','rogerbot',
@@ -1679,12 +1879,16 @@
 'SafeSearch[\x20]microdata[\x20]crawler','SafeSearch microdata crawler',
 'safesearch','safesearch ( catchall )',
 'SBL\-BOT','SBL-BOT',
+'scrapy','scrapy',
 'Screaming[\x20]Frog[\x20]SEO[\x20]Spider/','Screaming Frog SEO Spider',
 'ScreenerBot[\x20]Crawler[\x20]Beta','ScreenerBot Crawler Beta',
+'Scrubby','Scrubby',
 'Searchie/','Searchie',
+'SecurityResearch\.bot','Security Research Bot',
 'Seekmo','Seekmo',
 'semanticbot','semanticbot',
 'SemrushBot/','SemrushBot',
+'SemrushBot-SI','SemrushBot-SI',
 'seo\-audit\-check\-bot/','seo-audit-check-bot',
 'Seobility','Seobility',
 'SEOkicks\-Robot','SEOkicks-Robot',
@@ -1692,15 +1896,20 @@
 'SEOstats','SEOstats',
 'Seosys/Nutch','Seosys/Nutch',
 'Seoterritory\.com[\x20]bot','Seoterritory.com.bot',
+'serendeputy','serendeputy',
 'Shim\-Crawler','Shim-Crawler',
 'SiteExplorer/','SiteExplorer',
 'siteexplorer\.info','siteexplorer.info',
+'siteimprove','siteimprove',
 'Slackbot\-LinkExpanding','Slackbot-LinkExpanding',
 'SmabblerBot/','SmabblerBot',
 'Sogou[\x20]web[\x20]spider/','Sogou web spider',
 'special_archiver/','special_archiver',
 'Spiderbot/','Spiderbot',
+'SpuhexBot','SpuhexBot',
+'spyonweb','spyonweb',
 'ssearch_bot','ssearch_bot',
+'Streamline3Bot','Streamline3Bot',
 'SurdotlyBot/','SurdotlyBot',
 'SurveyBot/','SurveyBot',
 'taiil/Nutch','taiil/Nutch',
@@ -1710,24 +1919,34 @@
 'Test/Nutch','Test/Nutch',
 'Test[\x20]Spider','Test Spider',
 'TestCrawler','TestCrawler',
+'The[\x20]Knowledge[\x20]AI', 'The Knowledge AI',
+'TkBot','TkBot',
+'tracemyfile','tracemyfile',
+'trendiction','trendiction',
 'TurnitinBot/','TurnitinBot',
 'TurnitinBot','TurnitinBot',
 'TweetmemeBot/','TweetmemeBot',
 'UCY/Nutch','UCY/Nutch',
+'uni-leipzig\.de','uni-leipzig.de',
 'Uptimebot/','Uptimebot',
+'UptimeRobot/','UptimeRobot',
 'URL[\x20]Checker','URL Checker',
 'UXCrawlerBot','UXCrawlerBot',
 'Validator\.nu/','Validator.nu',
 'vBSEO','vBSEO',
 'vBulletin[\x20]via[\x20]PHP','vBulletin via PHP',
 'vebidoobot','vebidoobot',
+'vegi[\x20]bot','vegi bot',
+'Velen','Velen',
 'viz/Nutch','viz/Nutch',
 'VoilaBot','VoilaBot',
 'VORTEX/','VORTEX',
 'voyager/','voyager',
+'vuhuvBot','vuhuvBot',
 'W3C_Validator/','W3C_Validator',
 'W3C\-checklink/','W3C-checklink',
 'WBSearchBot/','WBSearchBot',
+'WbSrch/','WbSrch/',
 'WeSEE:Ads/PageBot','WeSEE:Ads/PageBot',
 'WeSEE:Ads/PictureBot','WeSEE:Ads/PictureBot',
 'WeSEE_Bot','WeSEE_Bot',
@@ -1743,8 +1962,11 @@
 'XoviBot/','XoviBot',
 'yacybot','yacybot',
 'Yahoo[\x20]Link[\x20]Preview','Yahoo Link Preview',
+'yak','yak-linkfluence',
 'YisouSpider','YisouSpider',
 'yoozBot','yoozBot',
+'Your\-Website\-Sucks','Your-Website-Sucks',
+'zoominfobot','zoominfobot',
 'zspider/','zspider',
 'ZumBot/','ZumBot',
 # below placed at end to catch some generics
@@ -1752,7 +1974,6 @@
 'ng/1\.','ng/1.',
 'ng/2\.','ng/2.',
 'libwww\-perl','libwww-perl',
-'CFNetwork','CFNetwork',
 'urllib','urllib',
 'javabee','javabee',
 'projectwf\-java\-test\-crawler','projectwf-java-test-crawler',
@@ -1780,6 +2001,7 @@
 'MSIE[\x20]4','MSIE 4 - ( Rogue Robot )',
 'MSIE[\x20]5','MSIE 5 - ( Rogue Robot )',
 'MSIE[\x20]6','MSIE 6 - ( Rogue Robot )',
+'MSIE\+6\.0\;','MSIE+6.0; - ( Rogue Robot)',
 'Windows[\x20]95','Windows 95 - ( Rogue Robot )',
 'Windows[\x20]98','Windows 99 - ( Rogue Robot )',
 
@@ -1900,7 +2122,6 @@
 'cyberspyder','cyberspyder',
 'datafountains/dmoz_downloader','datafountains/dmoz_downloader',
 'dataprovider\.com','dataprovider.com',
-'daumoa','daumoa',
 'daviesbot','daviesbot',
 'daylifefeedfetcher','daylifefeedfetcher',
 'daypopbot','daypopbot',
@@ -2406,6 +2627,8 @@
 'ucsd','ucsd',
 'udmsearch','udmsearch',
 'ultraseek','ultraseek',
+'um\-IC','ubermetrics-technologies.com',
+'um\-LN','ubermetrics-technologies.com',
 'unchaos_bot_hybrid_web_search_engine','unchaos_bot_hybrid_web_search_engine',
 'unido\-bot','unido-bot',
 'unisterbot','unisterbot',
@@ -2550,6 +2773,7 @@
 'sitemap','sitemap',
 'spider','spider',
 'sucker','sucker',
+'survey','survey',
 'validator','validator',
 'bot[\s_+:,\.\;\/\\\-]','Unknown robot identified by bot\*',
 '[\s_+:,\.\;\/\\\-]bot','Unknown robot identified by \*bot',
@@ -2557,6 +2781,8 @@
 'php','A PHP script',
 'ruby/','Ruby script',
 'no_user_agent','empty user agent string',
+# Moving oBot towards the end so it does not pick up other *obot robots
+'oBot/','oBot',
 # Unknown robots identified by hit on robots.txt
 'unknown','Unknown robot (identified by hit on robots.txt)'
 );
